@@ -19,8 +19,8 @@ dolloar_regex_compile = re.compile(r"\$\$")
 # variable notation, e.g. ${var} or $var
 variable_regex_compile = re.compile(r"\$\{(\w+)\}|\$(\w+)")
 # function notation, e.g. ${func1($var_1, $var_3)}
-# function_regex_compile = re.compile(r"\$\{(\w+)\(([\$\S\w\s=,]*)\)\}")
-function_regex_compile = re.compile(r"\$\{(\w+)\(([\$\}\)\[\]\'\,\(\{\w\;\!\:\*\.\-/\s\=\,]*)\)\}")
+function_regex_compile = re.compile(r"\$\{(\w+)\(([\$\S\w\s=,]*)\)\}")
+# function_regex_compile = re.compile(r"\$\{(\w+)\(([\$\}\)\[\]\'\,\(\{\w\;\!\:\*\.\-/\s\=\,]*)\)\}")
 
 suffix_regex_compile1 = r'\[\'(.*?)\'\]'
 suffix_regex_compile2 = r"\[(.*?)\]"
@@ -207,6 +207,7 @@ def parse_function_params(params: Text, func_name: Text) -> Dict:
     # todo bug kv形式传参时会报错
     if "${" in params_str and ")}" in params_str:
         args_list.append(params_str)
+        args_list = params_str.split(",")
     else:
         func_match = function_regex_compile.match(params_str, 0)
         if func_match:
