@@ -11,7 +11,7 @@ try:
     USE_ALLURE = True
 except ModuleNotFoundError:
     USE_ALLURE = False
-
+# import allure
 from loguru import logger
 
 from rrtv_httprunner import utils, exceptions
@@ -19,10 +19,6 @@ from rrtv_httprunner.client import HttpSession
 from rrtv_httprunner.exceptions import ValidationFailure, ParamsError
 from rrtv_httprunner.ext.uploader import prepare_upload_step
 from rrtv_httprunner.loader import load_project_meta, load_testcase_file
-from rrtv_httprunner.parser import build_url, parse_data, parse_variables_mapping
-from rrtv_httprunner.response import ResponseObject
-from rrtv_httprunner.testcase import Config, Step
-from rrtv_httprunner.utils import merge_variables
 from rrtv_httprunner.models import (
     TConfig,
     TStep,
@@ -33,8 +29,12 @@ from rrtv_httprunner.models import (
     TestCaseInOut,
     ProjectMeta,
     TestCase,
-    Hooks, data_enum,
+    Hooks, data_enum, AllureParameter,
 )
+from rrtv_httprunner.parser import build_url, parse_data, parse_variables_mapping
+from rrtv_httprunner.response import ResponseObject
+from rrtv_httprunner.testcase import Config, Step
+from rrtv_httprunner.utils import merge_variables
 
 
 class HttpRunner(object):
@@ -216,8 +216,13 @@ class HttpRunner(object):
         parsed_request_dict["verify"] = self.__config.verify
         parsed_request_dict["json"] = parsed_request_dict.pop("req_json", {})
 
+        a = AllureParameter()
+        parsed_request_dict["allure"] = a
         # request
         resp = self.__session.request(method, url, **parsed_request_dict)
+        if USE_ALLURE:
+            # update allure report meta
+            allure.attach(a.curl, "curl:", allure.attachment_type.TEXT)
         resp_obj = ResponseObject(resp)
         step.variables["response"] = resp_obj
 
@@ -504,11 +509,12 @@ class HttpRunner(object):
         self.__config.name = parse_data(
             self.__config.name, config_variables, self.__project_meta.functions
         )
-
+        url = str(self.__config.base_url if self.__config.base_url[-1] != "/" else self.__config.base_url[0:-2]) + str(
+            self.__teststeps[0].request.url)
         if USE_ALLURE:
             # update allure report meta
             allure.dynamic.title(self.__config.name)
-            allure.dynamic.description(f"TestCase ID: {self.__case_id}")
+            allure.dynamic.description(f"URL:{url}")
 
         logger.info(
             f"Start to run testcase: {self.__config.name}, TestCase ID: {self.__case_id}"
